struct RawVarZeroCow {
buf: NonNull<[u8]>,
owned: bool,
}Expand description
VarZeroCow without the V to simulate a dropck eyepatch
(i.e., prove to rustc that the dtor is not able to observe V or ’a)
This is effectively Cow<'a, [u8]>, with the lifetime managed externally
Fields
buf: NonNull<[u8]>Pointer to data
Safety Invariants
- This slice must always be valid as a byte slice
- If
ownedis true, this slice can be freed. VarZeroCow, the only user of this type, will impose an additional invariant that the buffer is a valid V
owned: boolThe buffer is Box<[u8]> if true
Implementations